==> haskell-monad-time-0.3.1.0-1-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-monad-time.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: monad-time
version: 0.3.1.0
id: monad-time-0.3.1.0-7HVH4vvpYhA8KnatzHBKCJ
key: monad-time-0.3.1.0-7HVH4vvpYhA8KnatzHBKCJ
license: BSD3
copyright: Scrive AB
maintainer: Andrzej Rybczak <andrzej@rybczak.net>,
            Jonathan Jouty <jonathan@scrive.com>,
            Mikhail Glushenkov <mikhail@scrive.com>
homepage: https://github.com/scrive/monad-time
synopsis: Type class for monads which carry
          the notion of the current time.
description:
    '\''MonadTime'\'' type class for monads
    which carry the notion of the current time.
category: Control
author: Andrzej Rybczak
exposed: True
indefinite: False
exposed-modules:
    Control.Monad.Time
abi: 49deb231202f2b228100ad7b18a6a009
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/monad-time-0.3.1.0
library-dirs: /usr/lib/ghc-8.2.2/site-local/monad-time-0.3.1.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/monad-time-0.3.1.0
hs-libraries: HSmonad-time-0.3.1.0-7HVH4vvpYhA8KnatzHBKCJ
depends:
    base-4.10.1.0 mtl-2.2.2-8XubxMJDT8QLsstvlNotkc time-1.8.0.2
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             mtl-2.2.2-8XubxMJDT8QLsstvlNotkc=9d788b97813db77c2d48570ade6e04a9
             time-1.8.0.2=d7392e85059cb108aeb68d6e24815970
haddock-interfaces: /usr/share/doc/haskell-monad-time/html/monad-time.haddock
haddock-html: /usr/share/doc/haskell-monad-time/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-monad-time-0.3.1.0-3-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-monad-time.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: monad-time
version: 0.3.1.0
id: monad-time-0.3.1.0-EBUQiIAH86L3Y0scTTbaUJ
key: monad-time-0.3.1.0-EBUQiIAH86L3Y0scTTbaUJ
license: BSD-3-Clause
copyright: Scrive AB
maintainer: Andrzej Rybczak <andrzej@rybczak.net>,
            Jonathan Jouty <jonathan@scrive.com>,
            Mikhail Glushenkov <mikhail@scrive.com>
author: Andrzej Rybczak
homepage: https://github.com/scrive/monad-time
synopsis: Type class for monads which carry
          the notion of the current time.
description:
    '\''MonadTime'\'' type class for monads
    which carry the notion of the current time.
category: Control
abi: 3b3735b94e7bbec23fc2968c7b0a63a8
exposed: True
exposed-modules:
    Control.Monad.Time
import-dirs: /usr/lib/ghc-8.4.3/site-local/monad-time-0.3.1.0
library-dirs: /usr/lib/ghc-8.4.3/site-local/monad-time-0.3.1.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/monad-time-0.3.1.0
hs-libraries: HSmonad-time-0.3.1.0-EBUQiIAH86L3Y0scTTbaUJ
depends:
    base-4.11.1.0 mtl-2.2.2 time-1.8.0.2
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             mtl-2.2.2=0b3b35c3b96c7607606ed10087c4aa4a
             time-1.8.0.2=042930fb6746cbaf3bc794f817f8a6b2
haddock-interfaces: /usr/share/doc/haskell-monad-time/html/monad-time.haddock
haddock-html: /usr/share/doc/haskell-monad-time/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
